Module relay

Module relay 

Nostr relay pool management.

Wraps nostr-sdk’s Client for relay connection, event publishing, and subscription.

Re-exports

pub use mock::MockRelayPool;

Modules

mock
In-memory mock relay pool for network-free testing.

Structs

RelayPool
Relay pool wrapper for managing Nostr relay connections.

Traits

RelayPoolTrait
Trait abstracting relay pool operations, enabling dependency injection and testing.