RelayPool

Struct RelayPool 

pub struct RelayPool { /* private fields */ }
Relay pool wrapper for managing Nostr relay connections.

Implementations

Source

impl RelayPool

pub async fn new<T>(signer: T) -> Result<Self>
where T: IntoNostrSigner,

Create a new relay pool with the given signer.

pub async fn connect(&self, relay_urls: &[String]) -> Result<()>

Connect to the given relay URLs.

pub async fn disconnect(&self) -> Result<()>

Disconnect from all relays.

pub async fn publish_event(&self, event: &Event) -> Result<EventId>

Publish a pre-built event to relays.

pub async fn publish(&self, builder: EventBuilder) -> Result<EventId>

Build, sign, and publish an event from a builder.

pub async fn sign(&self, builder: EventBuilder) -> Result<Event>

Sign an event builder without publishing.

pub fn client(&self) -> &Arc<Client>

Get the underlying nostr-sdk Client.

pub fn notifications(&self) -> Receiver<RelayPoolNotification>

Get notifications receiver for event streaming.

pub async fn public_key(&self) -> Result<PublicKey>

Get the public key of the signer.

pub async fn subscribe(&self, filters: Vec<Filter>) -> Result<()>

Subscribe to events matching filters.