pub struct Keys {
pub public_key: PublicKey,
/* private fields */
}Expand description
Nostr keys
Fields
public_key: PublicKeyPublic key
Implementations
Sourceimpl Keys
impl Keys
Sourcepub fn parse(secret_key: &str) -> Result<Keys, Error>
pub fn parse(secret_key: &str) -> Result<Keys, Error>
Parse secret key and construct keys.
Check SecretKey::parse to learn more about secret key parsing.
Sourcepub fn parse_with_ctx<C>(
secp: &Secp256k1<C>,
secret_key: &str,
) -> Result<Keys, Error>where
C: Signing,
pub fn parse_with_ctx<C>(
secp: &Secp256k1<C>,
secret_key: &str,
) -> Result<Keys, Error>where
C: Signing,
Parse secret key and construct keys.
Check SecretKey::parse to learn more about secret key parsing.
Sourcepub fn generate() -> Keys
pub fn generate() -> Keys
Generate random keys
This constructor uses a random number generator that retrieves randomness from the operating system (see OsRng).
Use Keys::generate_with_rng to specify a custom random source.
Check Keys::generate_with_ctx to learn more about how this constructor works internally.
Sourcepub fn generate_with_rng<R>(rng: &mut R) -> Keys
pub fn generate_with_rng<R>(rng: &mut R) -> Keys
Generate random keys using a custom random source
Check Keys::generate_with_ctx to learn more about how this constructor works internally.
Sourcepub fn generate_with_ctx<C, R>(secp: &Secp256k1<C>, rng: &mut R) -> Keys
pub fn generate_with_ctx<C, R>(secp: &Secp256k1<C>, rng: &mut R) -> Keys
Sourcepub fn public_key(&self) -> PublicKey
pub fn public_key(&self) -> PublicKey
Get public key
Sourcepub fn secret_key(&self) -> &SecretKey
pub fn secret_key(&self) -> &SecretKey
Get secret key
Sourcepub fn sign_schnorr(&self, message: &Message) -> Signature
pub fn sign_schnorr(&self, message: &Message) -> Signature