ContextVM Proxy โ connect to a remote Nostr MCP server as if local.
The proxy sends MCP requests over Nostr to a remote server and receives responses, making the remote server accessible locally.
Structs
- NostrMCP
Proxy - Proxy that connects to a remote MCP server via Nostr.
- Proxy
Config - Configuration for the proxy.