pub struct RelayPool { /* private fields */ }Expand description
Relay pool wrapper for managing Nostr relay connections.
Implementations
Sourceimpl RelayPool
impl RelayPool
Sourcepub async fn new<T>(signer: T) -> Result<Self>where
T: IntoNostrSigner,
pub async fn new<T>(signer: T) -> Result<Self>where
T: IntoNostrSigner,
Create a new relay pool with the given signer.
Sourcepub async fn connect(&self, relay_urls: &[String]) -> Result<()>
pub async fn connect(&self, relay_urls: &[String]) -> Result<()>
Connect to the given relay URLs.
Sourcepub async fn disconnect(&self) -> Result<()>
pub async fn disconnect(&self) -> Result<()>
Disconnect from all relays.
Sourcepub async fn publish_event(&self, event: &Event) -> Result<EventId>
pub async fn publish_event(&self, event: &Event) -> Result<EventId>
Publish a pre-built event to relays.
Sourcepub async fn publish(&self, builder: EventBuilder) -> Result<EventId>
pub async fn publish(&self, builder: EventBuilder) -> Result<EventId>
Build, sign, and publish an event from a builder.
Sourcepub async fn sign(&self, builder: EventBuilder) -> Result<Event>
pub async fn sign(&self, builder: EventBuilder) -> Result<Event>
Sign an event builder without publishing.
Sourcepub fn notifications(&self) -> Receiver<RelayPoolNotification>
pub fn notifications(&self) -> Receiver<RelayPoolNotification>
Get notifications receiver for event streaming.
Sourcepub async fn public_key(&self) -> Result<PublicKey>
pub async fn public_key(&self) -> Result<PublicKey>
Get the public key of the signer.